@@ -43,6 +43,7 @@ from lib import tags
 from lib import xml
 
 from lib.check.msgformat import c as msgformat_c
+from lib.check.msgformat import pybrace as msgformat_pybrace
 from lib.check.msgformat import python as msgformat_python
 from lib.check.msgrepr import message_repr
 
@@ -100,6 +101,7 @@ class Checker(object, metaclass=abc.ABCMeta):
         self._message_format_checkers = {
             'c': msgformat_c.Checker(self),
             'python': msgformat_python.Checker(self),
+            'python-brace': msgformat_pybrace.Checker(self),
         }
 
     @abc.abstractmethod
@@ -206,7 +208,7 @@ class Checker(object, metaclass=abc.ABCMeta):
             }
         regex = re.compile('|'.join(regexs))
         for line in ctx.file.header.splitlines():
-            match =  regex.search(line)
+            match = regex.search(line)
             if match is None:
                 continue
             self.tag('boilerplate-in-initial-comments', line)
@@ -649,6 +651,8 @@ class Checker(object, metaclass=abc.ABCMeta):
                 self.tag('invalid-report-msgid-bugs-to', report_msgid_bugs_to)
             elif email_address == 'EMAIL@ADDRESS':
                 self.tag('boilerplate-in-report-msgid-bugs-to', report_msgid_bugs_to)
+            elif domains.is_email_in_dotless_domain(email_address):
+                self.tag('invalid-report-msgid-bugs-to', report_msgid_bugs_to)
 
     @checks_header_fields('Last-Translator', 'Language-Team')
     def check_translator(self, ctx):
@@ -670,6 +674,8 @@ class Checker(object, metaclass=abc.ABCMeta):
             elif translator_email == 'EMAIL@ADDRESS':
                 if not ctx.is_template:
                     self.tag('boilerplate-in-last-translator', translator)
+            elif domains.is_email_in_dotless_domain(translator_email):
+                self.tag('invalid-last-translator', translator)
         # Language-Team:
         teams = ctx.metadata['Language-Team']
         if len(teams) > 1:
@@ -688,6 +694,8 @@ class Checker(object, metaclass=abc.ABCMeta):
             elif team_email in {'LL@li.org', 'EMAIL@ADDRESS'}:
                 if not ctx.is_template:
                     self.tag('boilerplate-in-language-team', team)
+            elif domains.is_email_in_dotless_domain(team_email):
+                self.tag('invalid-language-team', team)
             else:
                 translator = translator_emails.get(team_email)
                 if translator is not None:
