@@ -23,7 +23,10 @@ command-line interface
 '''
 
 import argparse
+import concurrent.futures
+import functools
 import io
+import multiprocessing
 import os
 import subprocess as ipc
 import sys
@@ -36,7 +39,7 @@ from lib import paths
 from lib import tags
 from lib import terminal
 
-__version__ = '0.23'
+__version__ = '0.25.1'
 
 def initialize_terminal():
     if sys.stdout.isatty():
@@ -62,7 +65,7 @@ class Checker(check.Checker):
         s = tag.format(self.fake_path, *extra, color=True)
         print(s)
 
-def check_file(filename, *, options):
+def check_regular_file(filename, *, options):
     checker_instance = Checker(filename, options=options)
     checker_instance.check()
 
@@ -106,16 +109,48 @@ def check_deb(filename, *, options):
                 if os.path.isfile(path):
                     check_file(path, options=options)
 
-def check_all(files, *, options):
-    for filename in files:
-        if options.unpack_deb:
-            try:
-                check_deb(filename, options=options)
-            except UnsupportedFileType:
-                pass
-            else:
-                continue
-        check_file(filename, options=options)
+def check_file(path, *, options):
+    if options.unpack_deb:
+        try:
+            return check_deb(path, options=options)
+        except UnsupportedFileType:
+            pass
+    return check_regular_file(path, options=options)
+
+def check_file_s(path, *, options):
+    '''
+    check_file() with captured stdout
+    '''
+    orig_stdout = sys.stdout
+    sys.stdout = io_stdout = io.StringIO()
+    try:
+        check_file(path, options=options)
+    finally:
+        sys.stdout = orig_stdout
+    return io_stdout.getvalue()
+
+def check_all(paths, *, options):
+    if (len(paths) <= 1) or (options.jobs <= 1):
+        for path in paths:
+            check_file(path, options=options)
+    else:
+        executor = concurrent.futures.ProcessPoolExecutor(max_workers=options.jobs)
+        with executor:
+            check_file_opt = functools.partial(check_file_s, options=options)
+            for s in executor.map(check_file_opt, paths):
+                sys.stdout.write(s)
+
+def parse_jobs(s):
+    if s == 'auto':
+        try:
+            return multiprocessing.cpu_count()
+        except NotImplementedError:
+            return 1
+    n = int(s)
+    if n <= 0:
+        raise ValueError
+    return n
+parse_jobs.__name__ = 'jobs'
 
 def main():
     initialize_terminal()
@@ -123,6 +158,8 @@ def main():
     ap.add_argument('--version', action='version', version='%(prog)s {}'.format(__version__))
     ap.add_argument('-l', '--language', metavar='<lang>', help='assume this language')
     ap.add_argument('--unpack-deb', action='store_true', help='allow unpacking Debian packages')
+    ap.add_argument('-j', '--jobs', type=parse_jobs, metavar='<n>', default=None, help='use <n> processes')
+    ap.add_argument('--parallel', type=int, metavar='<n>', default=None, help=argparse.SUPPRESS)  # renamed as -j/--jobs in 0.25
     ap.add_argument('--file-type', metavar='<file-type>', help=argparse.SUPPRESS)
     ap.add_argument('--traceback', action='store_true', help=argparse.SUPPRESS)
     ap.add_argument('files', metavar='<file>', nargs='+')
@@ -141,6 +178,12 @@ def main():
         language.remove_encoding()
         language.remove_nonlinguistic_modifier()
         options.language = language
+    if options.jobs is None:
+        if options.parallel is not None:
+            options.jobs = options.parallel
+    if options.jobs is None:
+        options.jobs = 1
+    del options.parallel
     options.ignore_tags = set()
     options.fake_root = None
     Checker.patch_environment()
