@@ -130,7 +130,7 @@ _short_x_escape_re = re.compile(r'''
 def polib_unescape(s):
     def unescape(match):
         s = match.group()
-        s = _short_x_escape_re.sub(r'\x0\1', s)
+        s = _short_x_escape_re.sub(r'\\x0\1', s)
         result = ast.literal_eval("b'{}'".format(s))
         try:
             return result.decode('ASCII')
