@@ -1,4 +1,4 @@
-# Copyright © 2012, 2013 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2012-2015 Jakub Wilk <jwilk@jwilk.net>
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the “Software”), to deal
@@ -27,9 +27,9 @@ import functools
 import os
 import re
 
-from . import misc
-from . import paths
-from . import terminal
+from lib import misc
+from lib import paths
+from lib import terminal
 
 @functools.total_ordering
 class OrderedObject(object):
@@ -236,4 +236,4 @@ def iter_tags():
 def get_tag(tagname):
     return _tags[tagname]
 
-# vim:ts=4 sw=4 et
+# vim:ts=4 sts=4 sw=4 et
